export declare type PaletteTypes = 'main' | 'pastel';
export declare type TPalette<ID = string> = {
    identifier: ID;
    backgroundColor: string;
    highlight: string;
};
export declare type MainPaletteColors = typeof mainPalette[number]['identifier'];
export declare type PastelPaletteColors = typeof pastelPalette[number]['identifier'];
export declare const mainPalette: readonly TPalette<"supportRed" | "supportPink" | "supportPurple" | "supportDarkPurple" | "supportDarkBlue" | "supportBlue" | "supportGreen" | "supportLightGreen" | "supportYellow" | "supportOrange" | "supportBrown" | "supportGreyDark">[];
export declare const pastelPalette: readonly TPalette<"supportPastelRed" | "supportPastelPink" | "supportPastelPurple" | "supportPastelDarkPurple" | "supportPastelDarkBlue" | "supportPastelBlue" | "supportPastelGreen" | "supportPastelLightGreen" | "supportPastelYellow" | "supportPastelOrange" | "supportPastelBrown" | "supportPastelGrey">[];
/**
 * Allows querying HEX value of a color by its name.
 * These colors are found in palette used by Color Picker component.
 *
 * @example
 * ```
 * getHexByColorName('main', 'supportRed') === '#f55549'
 * ```
 *
 * @param {PaletteTypes} paletteName Possible values are 'main' | 'pastel'
 * @param colorName Possible values depend on `paletteName`.
 * For example, for `main` is can be `supportRed`, while for `pastel` is can be `supportPastelRed`.
 * TypeScript will provide full autocomplete.
 * @returns {string} the HEX representation of a color that Color Picker component is using.
 */
export declare const getHexByColorName: <T extends PaletteTypes>(paletteName: T, colorName: T extends "main" ? "supportRed" | "supportPink" | "supportPurple" | "supportDarkPurple" | "supportDarkBlue" | "supportBlue" | "supportGreen" | "supportLightGreen" | "supportYellow" | "supportOrange" | "supportBrown" | "supportGreyDark" : "supportPastelRed" | "supportPastelPink" | "supportPastelPurple" | "supportPastelDarkPurple" | "supportPastelDarkBlue" | "supportPastelBlue" | "supportPastelGreen" | "supportPastelLightGreen" | "supportPastelYellow" | "supportPastelOrange" | "supportPastelBrown" | "supportPastelGrey") => string;
